@@ -55,6 +55,14 @@ export class GoogleAnalyticsTracker {
   trackScreenView(screenName) {
     GoogleAnalyticsBridge.trackScreenView(this.id, screenName);
   }
+  
+  /**
+   * Track the campaign from url
+   * @param  {String} urlString The url of the deep link
+   */
+  trackCampaignFromUrl(urlString) {
+    GoogleAnalyticsBridge.trackCampaignFromUrl(this.id, urlString);
+  }
 
   /**
    * Track an event that has occured
@@ -209,4 +217,12 @@ export class GoogleAnalyticsTracker {
   setSamplingRate(sampleRatio) {
     GoogleAnalyticsBridge.setSamplingRate(this.id, sampleRatio);
   }
+  
+  /**
+   * Sets the currency for tracking.
+   * @param {String} currencyCode The currency ISO 4217 code
+   */
+  setCurrency(currencyCode) {
+    GoogleAnalyticsBridge.setCurrency(this.id, currencyCode);
+  }
 }
